You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@subversion.apache.org by ju...@apache.org on 2015/11/12 09:59:58 UTC

svn commit: r1713980 [1/6] - in /subversion/branches/move-tracking-2/subversion: include/private/ libsvn_client/ libsvn_delta/ libsvn_ra/ libsvn_ra_local/ libsvn_repos/ libsvn_wc/ svnmover/

Author: julianfoad
Date: Thu Nov 12 08:59:57 2015
New Revision: 1713980

URL: http://svn.apache.org/viewvc?rev=1713980&view=rev
Log:
On the 'move-tracking-2' branch: Make all externally visible identifiers
private, by renaming them to contain a double underscore and begin with a
limited number of prefixes (svn_branch__, svn_element__, svn_eid__).

Modified:
    subversion/branches/move-tracking-2/subversion/include/private/svn_branch.h
    subversion/branches/move-tracking-2/subversion/include/private/svn_branch_compat.h
    subversion/branches/move-tracking-2/subversion/include/private/svn_branch_impl.h
    subversion/branches/move-tracking-2/subversion/include/private/svn_branch_nested.h
    subversion/branches/move-tracking-2/subversion/include/private/svn_branch_repos.h
    subversion/branches/move-tracking-2/subversion/include/private/svn_element.h
    subversion/branches/move-tracking-2/subversion/include/private/svn_ra_private.h
    subversion/branches/move-tracking-2/subversion/include/private/svn_wc_private.h
    subversion/branches/move-tracking-2/subversion/libsvn_client/switch.c
    subversion/branches/move-tracking-2/subversion/libsvn_client/update.c
    subversion/branches/move-tracking-2/subversion/libsvn_delta/branch.c
    subversion/branches/move-tracking-2/subversion/libsvn_delta/branch_compat.c
    subversion/branches/move-tracking-2/subversion/libsvn_delta/branch_nested.c
    subversion/branches/move-tracking-2/subversion/libsvn_delta/branch_repos.c
    subversion/branches/move-tracking-2/subversion/libsvn_delta/element.c
    subversion/branches/move-tracking-2/subversion/libsvn_delta/migrate.c
    subversion/branches/move-tracking-2/subversion/libsvn_ra/ra_loader.c
    subversion/branches/move-tracking-2/subversion/libsvn_ra/ra_loader.h
    subversion/branches/move-tracking-2/subversion/libsvn_ra_local/ra_plugin.c
    subversion/branches/move-tracking-2/subversion/libsvn_repos/commit.c
    subversion/branches/move-tracking-2/subversion/libsvn_wc/deprecated.c
    subversion/branches/move-tracking-2/subversion/libsvn_wc/update_editor.c
    subversion/branches/move-tracking-2/subversion/svnmover/merge3.c
    subversion/branches/move-tracking-2/subversion/svnmover/svnmover.c
    subversion/branches/move-tracking-2/subversion/svnmover/svnmover.h

Modified: subversion/branches/move-tracking-2/subversion/include/private/svn_branch.h
URL: http://svn.apache.org/viewvc/subversion/branches/move-tracking-2/subversion/include/private/svn_branch.h?rev=1713980&r1=1713979&r2=1713980&view=diff
==============================================================================
--- subversion/branches/move-tracking-2/subversion/include/private/svn_branch.h (original)
+++ subversion/branches/move-tracking-2/subversion/include/private/svn_branch.h Thu Nov 12 08:59:57 2015
@@ -66,11 +66,11 @@
  * - modify (not involving paths)
  *   => requires a txn
  *
- * Currently, a txn is represented by 'svn_branch_txn_t', with
- * 'svn_branch_state_t' for the individual branches in it. A flat tree is
- * represented by 'svn_branch_subtree_t'. But there is currently not a
+ * Currently, a txn is represented by 'svn_branch__txn_t', with
+ * 'svn_branch__state_t' for the individual branches in it. A flat tree is
+ * represented by 'svn_branch__subtree_t'. But there is currently not a
  * clean separation; there is some overlap and some warts such as the
- * 'svn_branch_txn_sequence_point' method.
+ * 'svn_branch__txn_sequence_point' method.
  */
 
 
@@ -92,7 +92,7 @@ extern "C" {
 
 
 /* ### */
-#define SVN_ERR_BRANCHING 123456
+#define SVN_BRANCH__ERR 123456
 
 /** Element Identifier (EID).
  *
@@ -109,43 +109,43 @@ extern "C" {
  *
  * ### In most places the code currently says 'int', verbatim.
  */
-typedef int svn_branch_eid_t;
+typedef int svn_branch__eid_t;
 
-typedef struct svn_branch_el_rev_id_t svn_branch_el_rev_id_t;
+typedef struct svn_branch__el_rev_id_t svn_branch__el_rev_id_t;
 
-typedef struct svn_branch_rev_bid_eid_t svn_branch_rev_bid_eid_t;
+typedef struct svn_branch__rev_bid_eid_t svn_branch__rev_bid_eid_t;
 
-typedef struct svn_branch_rev_bid_t svn_branch_rev_bid_t;
+typedef struct svn_branch__rev_bid_t svn_branch__rev_bid_t;
 
-typedef struct svn_branch_state_t svn_branch_state_t;
+typedef struct svn_branch__state_t svn_branch__state_t;
 
 /* Per-repository branching info.
  */
-typedef struct svn_branch_repos_t svn_branch_repos_t;
+typedef struct svn_branch__repos_t svn_branch__repos_t;
 
 /* Methods (conceptually public, but called indirectly) for a transaction.
  */
-typedef struct svn_branch_txn_vtable_t svn_branch_txn_vtable_t;
+typedef struct svn_branch__txn_vtable_t svn_branch__txn_vtable_t;
 
 /* Private data for a transaction.
  */
-typedef struct svn_branch_txn_priv_t svn_branch_txn_priv_t;
+typedef struct svn_branch__txn_priv_t svn_branch__txn_priv_t;
 
 /* A container for all the branching metadata for a specific revision (or
  * an uncommitted transaction).
  */
-typedef struct svn_branch_txn_t
+typedef struct svn_branch__txn_t
 {
   /* Methods (conceptually public, but called indirectly). */
-  svn_branch_txn_vtable_t *vtable;
+  svn_branch__txn_vtable_t *vtable;
 
   /* Private data. */
-  svn_branch_txn_priv_t *priv;
+  svn_branch__txn_priv_t *priv;
 
   /* Public data. */
 
   /* The repository in which this revision exists. */
-  svn_branch_repos_t *repos;
+  svn_branch__repos_t *repos;
 
   /* If committed, the revision number; else SVN_INVALID_REVNUM. */
   svn_revnum_t rev;
@@ -154,23 +154,23 @@ typedef struct svn_branch_txn_t
      on which this transaction is based. */
   svn_revnum_t base_rev;
 
-} svn_branch_txn_t;
+} svn_branch__txn_t;
 
 /* Create a new branch txn object.
  */
-svn_branch_txn_t *
-svn_branch_txn_create(const svn_branch_txn_vtable_t *vtable,
-                      svn_cancel_func_t cancel_func,
-                      void *cancel_baton,
-                      apr_pool_t *result_pool);
+svn_branch__txn_t *
+svn_branch__txn_create(const svn_branch__txn_vtable_t *vtable,
+                       svn_cancel_func_t cancel_func,
+                       void *cancel_baton,
+                       apr_pool_t *result_pool);
 
 /* Return all the branches in TXN.
  *
  * Return an empty array if there are none.
  */
 apr_array_header_t *
-svn_branch_txn_get_branches(const svn_branch_txn_t *txn,
-                            apr_pool_t *result_pool);
+svn_branch__txn_get_branches(const svn_branch__txn_t *txn,
+                             apr_pool_t *result_pool);
 
 /* Return the branch whose id is BRANCH_ID in TXN.
  *
@@ -180,24 +180,24 @@ svn_branch_txn_get_branches(const svn_br
  * current implementation it is constructed from the hierarchy of subbranch
  * root EIDs leading to the branch, but that may be changed in future.
  *
- * See also: svn_branch_get_id().
+ * See also: svn_branch__get_id().
  */
-svn_branch_state_t *
-svn_branch_txn_get_branch_by_id(const svn_branch_txn_t *txn,
-                                const char *branch_id,
-                                apr_pool_t *scratch_pool);
+svn_branch__state_t *
+svn_branch__txn_get_branch_by_id(const svn_branch__txn_t *txn,
+                                 const char *branch_id,
+                                 apr_pool_t *scratch_pool);
 
 svn_error_t *
-svn_branch_txn_get_num_new_eids(const svn_branch_txn_t *txn,
-                                int *num_new_eids_p,
-                                apr_pool_t *scratch_pool);
+svn_branch__txn_get_num_new_eids(const svn_branch__txn_t *txn,
+                                 int *num_new_eids_p,
+                                 apr_pool_t *scratch_pool);
 
 /* Assign a new txn-scope element id in TXN.
  */
 svn_error_t *
-svn_branch_txn_new_eid(svn_branch_txn_t *txn,
-                       int *new_eid_p,
-                       apr_pool_t *scratch_pool);
+svn_branch__txn_new_eid(svn_branch__txn_t *txn,
+                        int *new_eid_p,
+                        apr_pool_t *scratch_pool);
 
 /** Create a new branch or access an existing branch.
  *
@@ -220,21 +220,21 @@ svn_branch_txn_new_eid(svn_branch_txn_t
  *     ancestor?
  */
 svn_error_t *
-svn_branch_txn_open_branch(svn_branch_txn_t *txn,
-                           svn_branch_state_t **new_branch_p,
-                           svn_branch_rev_bid_t *predecessor,
-                           const char *new_branch_id,
-                           int root_eid,
-                           apr_pool_t *result_pool,
-                           apr_pool_t *scratch_pool);
+svn_branch__txn_open_branch(svn_branch__txn_t *txn,
+                            svn_branch__state_t **new_branch_p,
+                            svn_branch__rev_bid_t *predecessor,
+                            const char *new_branch_id,
+                            int root_eid,
+                            apr_pool_t *result_pool,
+                            apr_pool_t *scratch_pool);
 
 svn_error_t *
-svn_branch_txn_branch(svn_branch_txn_t *txn,
-                      svn_branch_state_t **new_branch_p,
-                      svn_branch_rev_bid_eid_t *from,
-                      const char *new_branch_id,
-                      apr_pool_t *result_pool,
-                      apr_pool_t *scratch_pool);
+svn_branch__txn_branch(svn_branch__txn_t *txn,
+                       svn_branch__state_t **new_branch_p,
+                       svn_branch__rev_bid_eid_t *from,
+                       const char *new_branch_id,
+                       apr_pool_t *result_pool,
+                       apr_pool_t *scratch_pool);
 
 /** Register a sequence point.
  *
@@ -247,27 +247,27 @@ svn_branch_txn_branch(svn_branch_txn_t *
  * state that is not a sequence point.
  *
  * The new transaction begins at a sequence point. Completion of editing
- * (svn_branch_txn_complete()) also creates a sequence point.
+ * (svn_branch__txn_complete()) also creates a sequence point.
  */
 svn_error_t *
-svn_branch_txn_sequence_point(svn_branch_txn_t *txn,
-                              apr_pool_t *scratch_pool);
+svn_branch__txn_sequence_point(svn_branch__txn_t *txn,
+                               apr_pool_t *scratch_pool);
 
 /** Finalize this transaction.
  *
  * Notify that the edit has been completed successfully.
  */
 svn_error_t *
-svn_branch_txn_complete(svn_branch_txn_t *txn,
-                        apr_pool_t *scratch_pool);
+svn_branch__txn_complete(svn_branch__txn_t *txn,
+                         apr_pool_t *scratch_pool);
 
 /** Abandon this transaction.
  *
  * Notify that editing this transaction was not successful.
  */
 svn_error_t *
-svn_branch_txn_abort(svn_branch_txn_t *txn,
-                     apr_pool_t *scratch_pool);
+svn_branch__txn_abort(svn_branch__txn_t *txn,
+                      apr_pool_t *scratch_pool);
 
 /* Change txn-local EIDs (negative integers) in TXN to revision EIDs, by
  * assigning a new revision-EID (positive integer) for each one.
@@ -275,8 +275,8 @@ svn_branch_txn_abort(svn_branch_txn_t *t
  * Rewrite TXN->first_eid and TXN->next_eid accordingly.
  */
 svn_error_t *
-svn_branch_txn_finalize_eids(svn_branch_txn_t *txn,
-                             apr_pool_t *scratch_pool);
+svn_branch__txn_finalize_eids(svn_branch__txn_t *txn,
+                              apr_pool_t *scratch_pool);
 
 /* Often, branches have the same root element. For example,
  * branching /trunk to /branches/br1 results in:
@@ -303,23 +303,23 @@ svn_branch_txn_finalize_eids(svn_branch_
 
 /* Methods (conceptually public, but called indirectly) for a branch state.
  */
-typedef struct svn_branch_state_vtable_t svn_branch_state_vtable_t;
+typedef struct svn_branch__state_vtable_t svn_branch__state_vtable_t;
 
 /* Private data for a branch state.
  */
-typedef struct svn_branch_state_priv_t svn_branch_state_priv_t;
+typedef struct svn_branch__state_priv_t svn_branch__state_priv_t;
 
 /* A branch state.
  *
  * A branch state object describes one version of one branch.
  */
-struct svn_branch_state_t
+struct svn_branch__state_t
 {
   /* Methods (conceptually public, but called indirectly). */
-  svn_branch_state_vtable_t *vtable;
+  svn_branch__state_vtable_t *vtable;
 
   /* Private data. */
-  svn_branch_state_priv_t *priv;
+  svn_branch__state_priv_t *priv;
 
   /* Public data. */
 
@@ -328,20 +328,20 @@ struct svn_branch_state_t
 
   /* The previous location in the lifeline of this branch. */
   /* (REV = -1 means "in this txn") */
-  svn_branch_rev_bid_t *predecessor;
+  svn_branch__rev_bid_t *predecessor;
 
   /* The revision to which this branch state belongs */
-  svn_branch_txn_t *txn;
+  svn_branch__txn_t *txn;
 
 };
 
 /* Create a new branch state object.
  */
-svn_branch_state_t *
-svn_branch_state_create(const svn_branch_state_vtable_t *vtable,
-                        svn_cancel_func_t cancel_func,
-                        void *cancel_baton,
-                        apr_pool_t *result_pool);
+svn_branch__state_t *
+svn_branch__state_create(const svn_branch__state_vtable_t *vtable,
+                         svn_cancel_func_t cancel_func,
+                         void *cancel_baton,
+                         apr_pool_t *result_pool);
 
 /* Get the full id of branch BRANCH.
  *
@@ -352,16 +352,16 @@ svn_branch_state_create(const svn_branch
  * current implementation it is constructed from the hierarchy of subbranch
  * root EIDs leading to the branch, but that may be changed in future.
  *
- * See also: svn_branch_txn_get_branch_by_id().
+ * See also: svn_branch__txn_get_branch_by_id().
  */
 const char *
-svn_branch_get_id(const svn_branch_state_t *branch,
-                  apr_pool_t *result_pool);
+svn_branch__get_id(const svn_branch__state_t *branch,
+                   apr_pool_t *result_pool);
 
 /* Return the element id of the root element of BRANCH.
  */
 int
-svn_branch_root_eid(const svn_branch_state_t *branch);
+svn_branch__root_eid(const svn_branch__state_t *branch);
 
 /* Return the id of the branch nested in OUTER_BID at element OUTER_EID.
  *
@@ -373,9 +373,9 @@ svn_branch_root_eid(const svn_branch_sta
  * element id.)
  */
 const char *
-svn_branch_id_nest(const char *outer_bid,
-                   int outer_eid,
-                   apr_pool_t *result_pool);
+svn_branch__id_nest(const char *outer_bid,
+                    int outer_eid,
+                    apr_pool_t *result_pool);
 
 /* Given a nested branch id BID, set *OUTER_BID to the outer branch's id
  * and *OUTER_EID to the nesting element in the outer branch.
@@ -388,17 +388,17 @@ svn_branch_id_nest(const char *outer_bid
  * element id.)
  */
 void
-svn_branch_id_unnest(const char **outer_bid,
-                     int *outer_eid,
-                     const char *bid,
-                     apr_pool_t *result_pool);
+svn_branch__id_unnest(const char **outer_bid,
+                      int *outer_eid,
+                      const char *bid,
+                      apr_pool_t *result_pool);
 
 /* Register the existence of BRANCH in TXN.
  */
 svn_error_t *
-svn_branch_txn_add_branch(svn_branch_txn_t *txn,
-                          svn_branch_state_t *branch,
-                          apr_pool_t *scratch_pool);
+svn_branch__txn_add_branch(svn_branch__txn_t *txn,
+                           svn_branch__state_t *branch,
+                           apr_pool_t *scratch_pool);
 
 /* Create a new branch with branch id BID, with no elements
  * (not even a root element).
@@ -407,25 +407,25 @@ svn_branch_txn_add_branch(svn_branch_txn
  *
  * Set the root element to ROOT_EID.
  */
-svn_branch_state_t *
-svn_branch_txn_add_new_branch(svn_branch_txn_t *txn,
-                              const char *bid,
-                              svn_branch_rev_bid_t *predecessor,
-                              int root_eid,
-                              apr_pool_t *scratch_pool);
+svn_branch__state_t *
+svn_branch__txn_add_new_branch(svn_branch__txn_t *txn,
+                               const char *bid,
+                               svn_branch__rev_bid_t *predecessor,
+                               int root_eid,
+                               apr_pool_t *scratch_pool);
 
 /* Remove the branch with id BID from the list of branches in TXN.
  */
 svn_error_t *
-svn_branch_txn_delete_branch(svn_branch_txn_t *txn,
-                             const char *bid,
-                             apr_pool_t *scratch_pool);
+svn_branch__txn_delete_branch(svn_branch__txn_t *txn,
+                              const char *bid,
+                              apr_pool_t *scratch_pool);
 
 /* Branch-Element-Revision */
-struct svn_branch_el_rev_id_t
+struct svn_branch__el_rev_id_t
 {
   /* The branch state that applies to REV. */
-  svn_branch_state_t *branch;
+  svn_branch__state_t *branch;
   /* Element. */
   int eid;
   /* Revision. SVN_INVALID_REVNUM means 'in this transaction', not 'head'.
@@ -435,7 +435,7 @@ struct svn_branch_el_rev_id_t
 };
 
 /* Revision-branch-element id. */
-struct svn_branch_rev_bid_eid_t
+struct svn_branch__rev_bid_eid_t
 {
   /* Revision. SVN_INVALID_REVNUM means 'in this transaction', not 'head'. */
   svn_revnum_t rev;
@@ -447,7 +447,7 @@ struct svn_branch_rev_bid_eid_t
 };
 
 /* Revision-branch id. */
-struct svn_branch_rev_bid_t
+struct svn_branch__rev_bid_t
 {
   /* Revision. SVN_INVALID_REVNUM means 'in this transaction', not 'head'. */
   svn_revnum_t rev;
@@ -459,51 +459,51 @@ struct svn_branch_rev_bid_t
 /* Return a new el_rev_id object constructed with *shallow* copies of BRANCH,
  * EID and REV, allocated in RESULT_POOL.
  */
-svn_branch_el_rev_id_t *
-svn_branch_el_rev_id_create(svn_branch_state_t *branch,
-                            int eid,
-                            svn_revnum_t rev,
-                            apr_pool_t *result_pool);
+svn_branch__el_rev_id_t *
+svn_branch__el_rev_id_create(svn_branch__state_t *branch,
+                             int eid,
+                             svn_revnum_t rev,
+                             apr_pool_t *result_pool);
 
 /* Return a new id object constructed with deep copies of REV, BRANCH_ID
  * and EID, allocated in RESULT_POOL.
  */
-svn_branch_rev_bid_eid_t *
-svn_branch_rev_bid_eid_create(svn_revnum_t rev,
-                              const char *branch_id,
-                              int eid,
-                              apr_pool_t *result_pool);
-svn_branch_rev_bid_t *
-svn_branch_rev_bid_create(svn_revnum_t rev,
-                          const char *branch_id,
-                          apr_pool_t *result_pool);
+svn_branch__rev_bid_eid_t *
+svn_branch__rev_bid_eid_create(svn_revnum_t rev,
+                               const char *branch_id,
+                               int eid,
+                               apr_pool_t *result_pool);
+svn_branch__rev_bid_t *
+svn_branch__rev_bid_create(svn_revnum_t rev,
+                           const char *branch_id,
+                           apr_pool_t *result_pool);
 
 /* Return a new id object constructed with a deep copy of OLD_ID,
  * allocated in RESULT_POOL. */
-svn_branch_rev_bid_eid_t *
-svn_branch_rev_bid_eid_dup(const svn_branch_rev_bid_eid_t *old_id,
-                           apr_pool_t *result_pool);
-svn_branch_rev_bid_t *
-svn_branch_rev_bid_dup(const svn_branch_rev_bid_t *old_id,
-                       apr_pool_t *result_pool);
+svn_branch__rev_bid_eid_t *
+svn_branch__rev_bid_eid_dup(const svn_branch__rev_bid_eid_t *old_id,
+                            apr_pool_t *result_pool);
+svn_branch__rev_bid_t *
+svn_branch__rev_bid_dup(const svn_branch__rev_bid_t *old_id,
+                        apr_pool_t *result_pool);
 
 
 /* Return the mapping of elements in branch BRANCH.
  */
 svn_error_t *
-svn_branch_state_get_elements(const svn_branch_state_t *branch,
-                              svn_element_tree_t **element_tree_p,
-                              apr_pool_t *result_pool);
+svn_branch__state_get_elements(const svn_branch__state_t *branch,
+                               svn_element__tree_t **element_tree_p,
+                               apr_pool_t *result_pool);
 
 /* In BRANCH, get element EID (parent, name, payload).
  *
  * If element EID is not present, return null.
  */
 svn_error_t *
-svn_branch_state_get_element(const svn_branch_state_t *branch,
-                             svn_element_content_t **element_p,
-                             int eid,
-                             apr_pool_t *result_pool);
+svn_branch__state_get_element(const svn_branch__state_t *branch,
+                              svn_element__content_t **element_p,
+                              int eid,
+                              apr_pool_t *result_pool);
 
 /** Specify that the element of @a branch identified by @a eid shall not
  * be present.
@@ -543,9 +543,9 @@ svn_branch_state_get_element(const svn_b
  *   granularity, which option to use.
  */
 svn_error_t *
-svn_branch_state_delete_one(svn_branch_state_t *branch,
-                           svn_branch_eid_t eid,
-                           apr_pool_t *scratch_pool);
+svn_branch__state_delete_one(svn_branch__state_t *branch,
+                             svn_branch__eid_t eid,
+                             apr_pool_t *scratch_pool);
 
 /** Specify the tree position and payload of the element of @a branch
  * identified by @a eid.
@@ -569,25 +569,25 @@ svn_branch_state_delete_one(svn_branch_s
  * Duplicate @a new_name and @a new_payload into the branch's pool.
  */
 svn_error_t *
-svn_branch_state_alter_one(svn_branch_state_t *branch,
-                           svn_branch_eid_t eid,
-                           svn_branch_eid_t new_parent_eid,
-                           const char *new_name,
-                           const svn_element_payload_t *new_payload,
-                           apr_pool_t *scratch_pool);
+svn_branch__state_alter_one(svn_branch__state_t *branch,
+                            svn_branch__eid_t eid,
+                            svn_branch__eid_t new_parent_eid,
+                            const char *new_name,
+                            const svn_element__payload_t *new_payload,
+                            apr_pool_t *scratch_pool);
 
 svn_error_t *
-svn_branch_state_copy_tree(svn_branch_state_t *branch,
-                           const svn_branch_rev_bid_eid_t *src_el_rev,
-                           svn_branch_eid_t new_parent_eid,
-                           const char *new_name,
-                           apr_pool_t *scratch_pool);
+svn_branch__state_copy_tree(svn_branch__state_t *branch,
+                            const svn_branch__rev_bid_eid_t *src_el_rev,
+                            svn_branch__eid_t new_parent_eid,
+                            const char *new_name,
+                            apr_pool_t *scratch_pool);
 
 /* Purge orphaned elements in BRANCH.
  */
 svn_error_t *
-svn_branch_state_purge(svn_branch_state_t *branch,
-                       apr_pool_t *scratch_pool);
+svn_branch__state_purge(svn_branch__state_t *branch,
+                        apr_pool_t *scratch_pool);
 
 /* Return the branch-relative path of element EID in BRANCH.
  *
@@ -596,9 +596,9 @@ svn_branch_state_purge(svn_branch_state_
  * ### TODO: Clarify sequencing requirements.
  */
 const char *
-svn_branch_get_path_by_eid(const svn_branch_state_t *branch,
-                           int eid,
-                           apr_pool_t *result_pool);
+svn_branch__get_path_by_eid(const svn_branch__state_t *branch,
+                            int eid,
+                            apr_pool_t *result_pool);
 
 /* Return the EID for the branch-relative path PATH in BRANCH.
  *
@@ -607,38 +607,38 @@ svn_branch_get_path_by_eid(const svn_bra
  * ### TODO: Clarify sequencing requirements.
  */
 int
-svn_branch_get_eid_by_path(const svn_branch_state_t *branch,
-                           const char *path,
-                           apr_pool_t *scratch_pool);
+svn_branch__get_eid_by_path(const svn_branch__state_t *branch,
+                            const char *path,
+                            apr_pool_t *scratch_pool);
 
 /* Get the default branching metadata for r0 of a new repository.
  */
 svn_string_t *
-svn_branch_get_default_r0_metadata(apr_pool_t *result_pool);
+svn_branch__get_default_r0_metadata(apr_pool_t *result_pool);
 
 /* Create a new txn object *TXN_P, initialized with info
  * parsed from STREAM, allocated in RESULT_POOL.
  */
 svn_error_t *
-svn_branch_txn_parse(svn_branch_txn_t **txn_p,
-                     svn_branch_repos_t *repos,
-                     svn_stream_t *stream,
-                     apr_pool_t *result_pool,
-                     apr_pool_t *scratch_pool);
+svn_branch__txn_parse(svn_branch__txn_t **txn_p,
+                      svn_branch__repos_t *repos,
+                      svn_stream_t *stream,
+                      apr_pool_t *result_pool,
+                      apr_pool_t *scratch_pool);
 
 /* Write to STREAM a parseable representation of TXN.
  */
 svn_error_t *
-svn_branch_txn_serialize(svn_branch_txn_t *txn,
-                         svn_stream_t *stream,
-                         apr_pool_t *scratch_pool);
+svn_branch__txn_serialize(svn_branch__txn_t *txn,
+                          svn_stream_t *stream,
+                          apr_pool_t *scratch_pool);
 
 /* Write to STREAM a parseable representation of BRANCH.
  */
 svn_error_t *
-svn_branch_state_serialize(svn_stream_t *stream,
-                           svn_branch_state_t *branch,
-                           apr_pool_t *scratch_pool);
+svn_branch__state_serialize(svn_stream_t *stream,
+                            svn_branch__state_t *branch,
+                            apr_pool_t *scratch_pool);
 
 
 #ifdef __cplusplus

Modified: subversion/branches/move-tracking-2/subversion/include/private/svn_branch_compat.h
URL: http://svn.apache.org/viewvc/subversion/branches/move-tracking-2/subversion/include/private/svn_branch_compat.h?rev=1713980&r1=1713979&r2=1713980&view=diff
==============================================================================
--- subversion/branches/move-tracking-2/subversion/include/private/svn_branch_compat.h (original)
+++ subversion/branches/move-tracking-2/subversion/include/private/svn_branch_compat.h Thu Nov 12 08:59:57 2015
@@ -67,7 +67,7 @@ extern "C" {
  * file therein, lives at least for the life time of @a result_pool.
  * @a scratch_pool is provided for temporary allocations.
  */
-typedef svn_error_t *(*svn_branch_compat__shim_fetch_func_t)(
+typedef svn_error_t *(*svn_branch__compat_fetch_func_t)(
   svn_node_kind_t *kind,
   apr_hash_t **props,
   svn_stringbuf_t **file_text,
@@ -82,17 +82,17 @@ typedef svn_error_t *(*svn_branch_compat
 /*
  */
 svn_error_t *
-svn_payload_fetch(svn_element_payload_t **payload_p,
-                  svn_branch_txn_t *txn,
-                  svn_element_branch_ref_t branch_ref,
-                  svn_branch_compat__shim_fetch_func_t fetch_func,
-                  void *fetch_baton,
-                  apr_pool_t *result_pool,
-                  apr_pool_t *scratch_pool);
+svn_branch__compat_fetch(svn_element__payload_t **payload_p,
+                         svn_branch__txn_t *txn,
+                         svn_element__branch_ref_t branch_ref,
+                         svn_branch__compat_fetch_func_t fetch_func,
+                         void *fetch_baton,
+                         apr_pool_t *result_pool,
+                         apr_pool_t *scratch_pool);
 
 /* An object for communicating out-of-band details between an Ev1-to-Ev3
  * shim and an Ev3-to-Ev1 shim. */
-typedef struct svn_branch_compat__shim_connector_t svn_branch_compat__shim_connector_t;
+typedef struct svn_branch__compat_shim_connector_t svn_branch__compat_shim_connector_t;
 
 /* Return an Ev3 editor in *EDITOR_P which will drive the Ev1 delta
  * editor DEDITOR/DEDIT_BATON.
@@ -132,14 +132,14 @@ typedef struct svn_branch_compat__shim_c
  * allocations.
  */
 svn_error_t *
-svn_branch_compat_txn_from_delta_for_commit(
-                        svn_branch_txn_t **txn_p,
-                        svn_branch_compat__shim_connector_t **shim_connector,
+svn_branch__compat_txn_from_delta_for_commit(
+                        svn_branch__txn_t **txn_p,
+                        svn_branch__compat_shim_connector_t **shim_connector,
                         const svn_delta_editor_t *deditor,
                         void *dedit_baton,
-                        svn_branch_txn_t *branching_txn,
+                        svn_branch__txn_t *branching_txn,
                         const char *repos_root_url,
-                        svn_branch_compat__shim_fetch_func_t fetch_func,
+                        svn_branch__compat_fetch_func_t fetch_func,
                         void *fetch_baton,
                         svn_cancel_func_t cancel_func,
                         void *cancel_baton,
@@ -164,15 +164,15 @@ svn_branch_compat_txn_from_delta_for_com
  * allocations.
  */
 svn_error_t *
-svn_branch_compat_delta_from_txn_for_commit(
+svn_branch__compat_delta_from_txn_for_commit(
                         const svn_delta_editor_t **deditor,
                         void **dedit_baton,
-                        svn_branch_txn_t *edit_txn,
+                        svn_branch__txn_t *edit_txn,
                         const char *repos_root_url,
                         const char *base_relpath,
-                        svn_branch_compat__shim_fetch_func_t fetch_func,
+                        svn_branch__compat_fetch_func_t fetch_func,
                         void *fetch_baton,
-                        const svn_branch_compat__shim_connector_t *shim_connector,
+                        const svn_branch__compat_shim_connector_t *shim_connector,
                         apr_pool_t *result_pool,
                         apr_pool_t *scratch_pool);
 
@@ -187,21 +187,21 @@ svn_branch_compat_delta_from_txn_for_com
  * original or copy-from kind/properties/text for a path being committed.
  */
 svn_error_t *
-svn_branch_compat__insert_shims(
+svn_branch__compat_insert_shims(
                         const svn_delta_editor_t **new_deditor,
                         void **new_dedit_baton,
                         const svn_delta_editor_t *old_deditor,
                         void *old_dedit_baton,
                         const char *repos_root,
                         const char *base_relpath,
-                        svn_branch_compat__shim_fetch_func_t fetch_func,
+                        svn_branch__compat_fetch_func_t fetch_func,
                         void *fetch_baton,
                         apr_pool_t *result_pool,
                         apr_pool_t *scratch_pool);
 
 /* A callback for declaring the target revision of an update or switch.
  */
-typedef svn_error_t *(*svn_branch_compat__set_target_revision_func_t)(
+typedef svn_error_t *(*svn_branch__compat_set_target_revision_func_t)(
   void *baton,
   svn_revnum_t target_revision,
   apr_pool_t *scratch_pool);
@@ -211,29 +211,29 @@ typedef svn_error_t *(*svn_branch_compat
  * This consists of a plain Ev3 editor and the additional methods or
  * resources needed for use as an update or switch editor.
  */
-typedef struct svn_update_editor3_t {
+typedef struct svn_branch__compat_update_editor3_t {
   /* The txn we're driving. */
-  svn_branch_txn_t *edit_txn;
+  svn_branch__txn_t *edit_txn;
 
   /* A method to communicate the target revision of the update (or switch),
    * to be called before driving the editor. It has its own baton, rather
    * than using the editor's baton, so that the editor can be replaced (by
    * a wrapper editor, typically) without having to wrap this callback. */
-  svn_branch_compat__set_target_revision_func_t set_target_revision_func;
+  svn_branch__compat_set_target_revision_func_t set_target_revision_func;
   void *set_target_revision_baton;
-} svn_update_editor3_t;
+} svn_branch__compat_update_editor3_t;
 
 /* Like svn_delta__ev3_from_delta_for_commit() but for an update editor.
  */
 svn_error_t *
-svn_branch_compat_txn_from_delta_for_update(
-                        svn_update_editor3_t **editor_p,
+svn_branch__compat_txn_from_delta_for_update(
+                        svn_branch__compat_update_editor3_t **editor_p,
                         const svn_delta_editor_t *deditor,
                         void *dedit_baton,
-                        svn_branch_txn_t *branching_txn,
+                        svn_branch__txn_t *branching_txn,
                         const char *repos_root_url,
                         const char *base_repos_relpath,
-                        svn_branch_compat__shim_fetch_func_t fetch_func,
+                        svn_branch__compat_fetch_func_t fetch_func,
                         void *fetch_baton,
                         svn_cancel_func_t cancel_func,
                         void *cancel_baton,
@@ -243,13 +243,13 @@ svn_branch_compat_txn_from_delta_for_upd
 /* Like svn_delta__delta_from_ev3_for_commit() but for an update editor.
  */
 svn_error_t *
-svn_branch_compat_delta_from_txn_for_update(
+svn_branch__compat_delta_from_txn_for_update(
                         const svn_delta_editor_t **deditor,
                         void **dedit_baton,
-                        svn_update_editor3_t *update_editor,
+                        svn_branch__compat_update_editor3_t *update_editor,
                         const char *repos_root_url,
                         const char *base_repos_relpath,
-                        svn_branch_compat__shim_fetch_func_t fetch_func,
+                        svn_branch__compat_fetch_func_t fetch_func,
                         void *fetch_baton,
                         apr_pool_t *result_pool,
                         apr_pool_t *scratch_pool);
@@ -257,12 +257,13 @@ svn_branch_compat_delta_from_txn_for_upd
 /* An Ev1 editor that drives (heuristically) a move-tracking editor.
  */
 svn_error_t *
-svn_branch_get_migration_editor(const svn_delta_editor_t **old_editor,
-                                void **old_edit_baton,
-                                svn_branch_txn_t *edit_txn,
-                                svn_ra_session_t *from_session,
-                                svn_revnum_t revision,
-                                apr_pool_t *result_pool);
+svn_branch__compat_get_migration_editor(
+                        const svn_delta_editor_t **old_editor,
+                        void **old_edit_baton,
+                        svn_branch__txn_t *edit_txn,
+                        svn_ra_session_t *from_session,
+                        svn_revnum_t revision,
+                        apr_pool_t *result_pool);
 
 
 #ifdef __cplusplus

Modified: subversion/branches/move-tracking-2/subversion/include/private/svn_branch_impl.h
URL: http://svn.apache.org/viewvc/subversion/branches/move-tracking-2/subversion/include/private/svn_branch_impl.h?rev=1713980&r1=1713979&r2=1713980&view=diff
==============================================================================
--- subversion/branches/move-tracking-2/subversion/include/private/svn_branch_impl.h (original)
+++ subversion/branches/move-tracking-2/subversion/include/private/svn_branch_impl.h Thu Nov 12 08:59:57 2015
@@ -37,7 +37,7 @@ extern "C" {
 
 
 /* Common aspects od a txn/branch 'editor' class (derived from Ev2) */
-typedef struct svn_vtable_priv_t
+typedef struct svn_branch__vtable_priv_t
 {
   /* Standard cancellation function. Called before each callback.  */
   svn_cancel_func_t cancel_func;
@@ -49,161 +49,161 @@ typedef struct svn_vtable_priv_t
   apr_pool_t *state_pool;
 #endif
 
-} svn_vtable_priv_t;
+} svn_branch__vtable_priv_t;
 
-/* The methods of svn_branch_txn_t.
+/* The methods of svn_branch__txn_t.
  * See the corresponding public API functions for details.
  */
 
-typedef apr_array_header_t *(*branch_txn_v_get_branches_t)(
-  const svn_branch_txn_t *txn,
+typedef apr_array_header_t *(*svn_branch__txn_v_get_branches_t)(
+  const svn_branch__txn_t *txn,
   apr_pool_t *result_pool);
 
-typedef svn_error_t *(*branch_txn_v_add_branch_t)(
-  svn_branch_txn_t *txn,
-  svn_branch_state_t *branch,
+typedef svn_error_t *(*svn_branch__txn_v_add_branch_t)(
+  svn_branch__txn_t *txn,
+  svn_branch__state_t *branch,
   apr_pool_t *scratch_pool);
 
-typedef svn_branch_state_t *(*branch_txn_v_add_new_branch_t)(
-  svn_branch_txn_t *txn,
+typedef svn_branch__state_t *(*svn_branch__txn_v_add_new_branch_t)(
+  svn_branch__txn_t *txn,
   const char *bid,
-  svn_branch_rev_bid_t *predecessor,
+  svn_branch__rev_bid_t *predecessor,
   int root_eid,
   apr_pool_t *scratch_pool);
 
-typedef svn_error_t *(*branch_txn_v_delete_branch_t)(
-  svn_branch_txn_t *txn,
+typedef svn_error_t *(*svn_branch__txn_v_delete_branch_t)(
+  svn_branch__txn_t *txn,
   const char *bid,
   apr_pool_t *scratch_pool);
 
-typedef svn_error_t *(*branch_txn_v_get_num_new_eids_t)(
-  const svn_branch_txn_t *txn,
+typedef svn_error_t *(*svn_branch__txn_v_get_num_new_eids_t)(
+  const svn_branch__txn_t *txn,
   int *num_new_eids_p,
   apr_pool_t *scratch_pool);
 
-typedef svn_error_t *(*branch_txn_v_new_eid_t)(
-  svn_branch_txn_t *txn,
-  svn_branch_eid_t *eid_p,
+typedef svn_error_t *(*svn_branch__txn_v_new_eid_t)(
+  svn_branch__txn_t *txn,
+  svn_branch__eid_t *eid_p,
   apr_pool_t *scratch_pool);
 
-typedef svn_error_t *(*branch_txn_v_open_branch_t)(
-  svn_branch_txn_t *txn,
-  svn_branch_state_t **new_branch_p,
-  svn_branch_rev_bid_t *predecessor,
+typedef svn_error_t *(*svn_branch__txn_v_open_branch_t)(
+  svn_branch__txn_t *txn,
+  svn_branch__state_t **new_branch_p,
+  svn_branch__rev_bid_t *predecessor,
   const char *new_branch_id,
   int root_eid,
   apr_pool_t *result_pool,
   apr_pool_t *scratch_pool);
 
-typedef svn_error_t *(*branch_txn_v_branch_t)(
-  svn_branch_txn_t *txn,
-  svn_branch_state_t **new_branch_p,
-  svn_branch_rev_bid_eid_t *from,
+typedef svn_error_t *(*svn_branch__txn_v_branch_t)(
+  svn_branch__txn_t *txn,
+  svn_branch__state_t **new_branch_p,
+  svn_branch__rev_bid_eid_t *from,
   const char *new_branch_id,
   apr_pool_t *result_pool,
   apr_pool_t *scratch_pool);
 
-typedef svn_error_t *(*branch_txn_v_finalize_eids_t)(
-  svn_branch_txn_t *txn,
+typedef svn_error_t *(*svn_branch__txn_v_finalize_eids_t)(
+  svn_branch__txn_t *txn,
   apr_pool_t *scratch_pool);
 
-typedef svn_error_t *(*branch_txn_v_serialize_t)(
-  svn_branch_txn_t *txn,
+typedef svn_error_t *(*svn_branch__txn_v_serialize_t)(
+  svn_branch__txn_t *txn,
   svn_stream_t *stream,
   apr_pool_t *scratch_pool);
 
-typedef svn_error_t *(*branch_txn_v_sequence_point_t)(
-  svn_branch_txn_t *txn,
+typedef svn_error_t *(*svn_branch__txn_v_sequence_point_t)(
+  svn_branch__txn_t *txn,
   apr_pool_t *scratch_pool);
 
-typedef svn_error_t *(*branch_txn_v_complete_t)(
-  svn_branch_txn_t *txn,
+typedef svn_error_t *(*svn_branch__txn_v_complete_t)(
+  svn_branch__txn_t *txn,
   apr_pool_t *scratch_pool);
 
-typedef svn_error_t *(*branch_txn_v_abort_t)(
-  svn_branch_txn_t *txn,
+typedef svn_error_t *(*svn_branch__txn_v_abort_t)(
+  svn_branch__txn_t *txn,
   apr_pool_t *scratch_pool);
 
-struct svn_branch_txn_vtable_t
+struct svn_branch__txn_vtable_t
 {
-  svn_vtable_priv_t vpriv;
+  svn_branch__vtable_priv_t vpriv;
 
   /* Methods. */
-  branch_txn_v_get_branches_t get_branches;
-  branch_txn_v_add_branch_t add_branch;
-  branch_txn_v_add_new_branch_t add_new_branch;
-  branch_txn_v_delete_branch_t delete_branch;
-  branch_txn_v_get_num_new_eids_t get_num_new_eids;
-  branch_txn_v_new_eid_t new_eid;
-  branch_txn_v_open_branch_t open_branch;
-  branch_txn_v_branch_t branch;
-  branch_txn_v_finalize_eids_t finalize_eids;
-  branch_txn_v_serialize_t serialize;
-  branch_txn_v_sequence_point_t sequence_point;
-  branch_txn_v_complete_t complete;
-  branch_txn_v_complete_t abort;
+  svn_branch__txn_v_get_branches_t get_branches;
+  svn_branch__txn_v_add_branch_t add_branch;
+  svn_branch__txn_v_add_new_branch_t add_new_branch;
+  svn_branch__txn_v_delete_branch_t delete_branch;
+  svn_branch__txn_v_get_num_new_eids_t get_num_new_eids;
+  svn_branch__txn_v_new_eid_t new_eid;
+  svn_branch__txn_v_open_branch_t open_branch;
+  svn_branch__txn_v_branch_t branch;
+  svn_branch__txn_v_finalize_eids_t finalize_eids;
+  svn_branch__txn_v_serialize_t serialize;
+  svn_branch__txn_v_sequence_point_t sequence_point;
+  svn_branch__txn_v_complete_t complete;
+  svn_branch__txn_v_complete_t abort;
 
 };
 
-/* The methods of svn_branch_state_t.
+/* The methods of svn_branch__state_t.
  * See the corresponding public API functions for details.
  */
 
-typedef svn_error_t *(*branch_state_v_get_elements_t)(
-  const svn_branch_state_t *branch,
-  svn_element_tree_t **element_tree_p,
+typedef svn_error_t *(*svn_branch__state_v_get_elements_t)(
+  const svn_branch__state_t *branch,
+  svn_element__tree_t **element_tree_p,
   apr_pool_t *result_pool);
 
-typedef svn_error_t *(*branch_state_v_get_element_t)(
-  const svn_branch_state_t *branch,
-  svn_element_content_t **element_p,
+typedef svn_error_t *(*svn_branch__state_v_get_element_t)(
+  const svn_branch__state_t *branch,
+  svn_element__content_t **element_p,
   int eid,
   apr_pool_t *result_pool);
 
-typedef svn_error_t *(*branch_state_v_alter_one_t)(
-  svn_branch_state_t *branch,
-  svn_branch_eid_t eid,
-  svn_branch_eid_t new_parent_eid,
+typedef svn_error_t *(*svn_branch__state_v_alter_one_t)(
+  svn_branch__state_t *branch,
+  svn_branch__eid_t eid,
+  svn_branch__eid_t new_parent_eid,
   const char *new_name,
-  const svn_element_payload_t *new_payload,
+  const svn_element__payload_t *new_payload,
   apr_pool_t *scratch_pool);
 
-typedef svn_error_t *(*branch_state_v_copy_one_t)(
-  svn_branch_state_t *branch,
-  const svn_branch_rev_bid_eid_t *src_el_rev,
-  svn_branch_eid_t local_eid,
-  svn_branch_eid_t new_parent_eid,
+typedef svn_error_t *(*svn_branch__state_v_copy_one_t)(
+  svn_branch__state_t *branch,
+  const svn_branch__rev_bid_eid_t *src_el_rev,
+  svn_branch__eid_t local_eid,
+  svn_branch__eid_t new_parent_eid,
   const char *new_name,
-  const svn_element_payload_t *new_payload,
+  const svn_element__payload_t *new_payload,
   apr_pool_t *scratch_pool);
 
-typedef svn_error_t *(*branch_state_v_copy_tree_t)(
-  svn_branch_state_t *branch,
-  const svn_branch_rev_bid_eid_t *src_el_rev,
-  svn_branch_eid_t new_parent_eid,
+typedef svn_error_t *(*svn_branch__state_v_copy_tree_t)(
+  svn_branch__state_t *branch,
+  const svn_branch__rev_bid_eid_t *src_el_rev,
+  svn_branch__eid_t new_parent_eid,
   const char *new_name,
   apr_pool_t *scratch_pool);
 
-typedef svn_error_t *(*branch_state_v_delete_one_t)(
-  svn_branch_state_t *branch,
-  svn_branch_eid_t eid,
+typedef svn_error_t *(*svn_branch__state_v_delete_one_t)(
+  svn_branch__state_t *branch,
+  svn_branch__eid_t eid,
   apr_pool_t *scratch_pool);
 
-typedef svn_error_t *(*branch_state_v_purge_t)(
-  svn_branch_state_t *branch,
+typedef svn_error_t *(*svn_branch__state_v_purge_t)(
+  svn_branch__state_t *branch,
   apr_pool_t *scratch_pool);
 
-struct svn_branch_state_vtable_t
+struct svn_branch__state_vtable_t
 {
-  svn_vtable_priv_t vpriv;
+  svn_branch__vtable_priv_t vpriv;
 
-  branch_state_v_get_elements_t get_elements;
-  branch_state_v_get_element_t get_element;
-  branch_state_v_alter_one_t alter_one;
-  branch_state_v_copy_one_t copy_one;
-  branch_state_v_copy_tree_t copy_tree;
-  branch_state_v_delete_one_t delete_one;
-  branch_state_v_purge_t purge;
+  svn_branch__state_v_get_elements_t get_elements;
+  svn_branch__state_v_get_element_t get_element;
+  svn_branch__state_v_alter_one_t alter_one;
+  svn_branch__state_v_copy_one_t copy_one;
+  svn_branch__state_v_copy_tree_t copy_tree;
+  svn_branch__state_v_delete_one_t delete_one;
+  svn_branch__state_v_purge_t purge;
 
 };
 

Modified: subversion/branches/move-tracking-2/subversion/include/private/svn_branch_nested.h
URL: http://svn.apache.org/viewvc/subversion/branches/move-tracking-2/subversion/include/private/svn_branch_nested.h?rev=1713980&r1=1713979&r2=1713980&view=diff
==============================================================================
--- subversion/branches/move-tracking-2/subversion/include/private/svn_branch_repos.h (original)
+++ subversion/branches/move-tracking-2/subversion/include/private/svn_branch_repos.h Thu Nov 12 08:59:57 2015
@@ -42,8 +42,8 @@ extern "C" {
 
 
 /* Create a new branching metadata object */
-svn_branch_repos_t *
-svn_branch_repos_create(apr_pool_t *result_pool);
+svn_branch__repos_t *
+svn_branch__repos_create(apr_pool_t *result_pool);
 
 /* Add REV_ROOT as the next revision in the repository REPOS.
  *
@@ -51,31 +51,31 @@ svn_branch_repos_create(apr_pool_t *resu
  * caller should set those, before or after this call.)
  */
 svn_error_t *
-svn_branch_repos_add_revision(svn_branch_repos_t *repos,
-                              svn_branch_txn_t *rev_root);
+svn_branch__repos_add_revision(svn_branch__repos_t *repos,
+                               svn_branch__txn_t *rev_root);
 
 /* Return a pointer to revision REVNUM of the repository REPOS.
  */
-struct svn_branch_txn_t *
-svn_branch_repos_get_revision(const svn_branch_repos_t *repos,
-                              svn_revnum_t revnum);
+struct svn_branch__txn_t *
+svn_branch__repos_get_revision(const svn_branch__repos_t *repos,
+                               svn_revnum_t revnum);
 
 /* Return the revision root that represents the base revision (or,
  * potentially, txn) of the revision or txn REV_ROOT.
  */
-svn_branch_txn_t *
-svn_branch_repos_get_base_revision_root(svn_branch_txn_t *rev_root);
+svn_branch__txn_t *
+svn_branch__repos_get_base_revision_root(svn_branch__txn_t *rev_root);
 
 /* Set *BRANCH_P to the branch found in REPOS : REVNUM : BRANCH_ID.
  *
  * Return an error if REVNUM or BRANCH_ID is not found.
  */
 svn_error_t *
-svn_branch_repos_get_branch_by_id(svn_branch_state_t **branch_p,
-                                  const svn_branch_repos_t *repos,
-                                  svn_revnum_t revnum,
-                                  const char *branch_id,
-                                  apr_pool_t *scratch_pool);
+svn_branch__repos_get_branch_by_id(svn_branch__state_t **branch_p,
+                                   const svn_branch__repos_t *repos,
+                                   svn_revnum_t revnum,
+                                   const char *branch_id,
+                                   apr_pool_t *scratch_pool);
 
 /* Set *EL_REV_P to the el-rev-id of the element at branch id BRANCH_ID,
  * element id EID, in revision REVNUM in REPOS.
@@ -88,13 +88,13 @@ svn_branch_repos_get_branch_by_id(svn_br
  * RESULT_POOL.
  */
 svn_error_t *
-svn_branch_repos_find_el_rev_by_id(svn_branch_el_rev_id_t **el_rev_p,
-                                   const svn_branch_repos_t *repos,
-                                   svn_revnum_t revnum,
-                                   const char *branch_id,
-                                   int eid,
-                                   apr_pool_t *result_pool,
-                                   apr_pool_t *scratch_pool);
+svn_branch__repos_find_el_rev_by_id(svn_branch__el_rev_id_t **el_rev_p,
+                                    const svn_branch__repos_t *repos,
+                                    svn_revnum_t revnum,
+                                    const char *branch_id,
+                                    int eid,
+                                    apr_pool_t *result_pool,
+                                    apr_pool_t *scratch_pool);
 
 
 #ifdef __cplusplus

Modified: subversion/branches/move-tracking-2/subversion/include/private/svn_element.h
URL: http://svn.apache.org/viewvc/subversion/branches/move-tracking-2/subversion/include/private/svn_element.h?rev=1713980&r1=1713979&r2=1713980&view=diff
==============================================================================
--- subversion/branches/move-tracking-2/subversion/include/private/svn_element.h (original)
+++ subversion/branches/move-tracking-2/subversion/include/private/svn_element.h Thu Nov 12 08:59:57 2015
@@ -26,8 +26,8 @@
  * @since New in 1.10.
  */
 
-#ifndef SVN_ELEMENT_H
-#define SVN_ELEMENT_H
+#ifndef SVN_BRANCH_ELEMENT_H
+#define SVN_BRANCH_ELEMENT_H
 
 #include <apr_pools.h>
 #include <apr_tables.h>
@@ -43,18 +43,18 @@ extern "C" {
 
 /** Like apr_hash_get() but the hash key is an integer. */
 void *
-svn_eid_hash_get(apr_hash_t *ht,
-                 int key);
+svn_eid__hash_get(apr_hash_t *ht,
+                  int key);
 
 /** Like apr_hash_set() but the hash key is an integer. */
 void
-svn_eid_hash_set(apr_hash_t *ht,
-                 int key,
-                 const void *val);
+svn_eid__hash_set(apr_hash_t *ht,
+                  int key,
+                  const void *val);
 
 /** Like apr_hash_this_key() but the hash key is an integer. */
 int
-svn_eid_hash_this_key(apr_hash_index_t *hi);
+svn_eid__hash_this_key(apr_hash_index_t *hi);
 
 struct svn_sort__item_t;
 
@@ -106,12 +106,12 @@ svn_eid__hash_sort_compare_items_by_eid(
 
 /**
  */
-typedef struct svn_element_branch_ref_t
+typedef struct svn_element__branch_ref_t
 {
   svn_revnum_t rev;
   const char *branch_id;
   int eid;
-} svn_element_branch_ref_t;
+} svn_element__branch_ref_t;
 
 /** Versioned payload of an element, excluding tree structure information.
  *
@@ -126,7 +126,7 @@ typedef struct svn_element_branch_ref_t
  *     payload and the client may record an 'absent' WC node. (This
  *     would not make sense in a commit.)
  */
-typedef struct svn_element_payload_t svn_element_payload_t;
+typedef struct svn_element__payload_t svn_element__payload_t;
 
 /*
  * ========================================================================
@@ -150,7 +150,7 @@ typedef struct svn_element_payload_t svn
  * ### Idea for the future: Specify payload as an (optional) reference
  *     plus (optional) overrides or deltas against the reference?
  */
-struct svn_element_payload_t
+struct svn_element__payload_t
 {
   /* Is this a subbranch-root element, in other words a link to a nested
    * branch? If so, all other fields are irrelevant. */
@@ -162,7 +162,7 @@ struct svn_element_payload_t
   /* Reference an existing, committed payload. (Use with kind=unknown if
    * there is no content in props/text/targe fields.)
    * The 'null' value is (SVN_INVALID_REVNUM, NULL, *). */
-  svn_element_branch_ref_t branch_ref;
+  svn_element__branch_ref_t branch_ref;
 
   /* The pool in which the payload's content is allocated. Used when
    * resolving (populating the props/text/target in) a payload that was
@@ -186,29 +186,29 @@ struct svn_element_payload_t
 /* Return true iff PAYLOAD satisfies all its invariants.
  */
 svn_boolean_t
-svn_element_payload_invariants(const svn_element_payload_t *payload);
+svn_element__payload_invariants(const svn_element__payload_t *payload);
 
 /** Duplicate a node-payload @a old into @a result_pool.
  */
-svn_element_payload_t *
-svn_element_payload_dup(const svn_element_payload_t *old,
-                        apr_pool_t *result_pool);
+svn_element__payload_t *
+svn_element__payload_dup(const svn_element__payload_t *old,
+                         apr_pool_t *result_pool);
 
 /* Return true iff the payload of LEFT is identical to that of RIGHT.
  * References are not supported. Node kind 'unknown' is not supported.
  */
 svn_boolean_t
-svn_element_payload_equal(const svn_element_payload_t *left,
-                          const svn_element_payload_t *right,
-                          apr_pool_t *scratch_pool);
+svn_element__payload_equal(const svn_element__payload_t *left,
+                           const svn_element__payload_t *right,
+                           apr_pool_t *scratch_pool);
 
 /** Create a new node-payload object for a subbranch-root (link to a
  * nested branch).
  *
  * Allocate the result in @a result_pool.
  */
-svn_element_payload_t *
-svn_element_payload_create_subbranch(apr_pool_t *result_pool);
+svn_element__payload_t *
+svn_element__payload_create_subbranch(apr_pool_t *result_pool);
 
 /** Create a new node-payload object by reference to an existing payload.
  *
@@ -216,37 +216,37 @@ svn_element_payload_create_subbranch(apr
  *
  * Allocate the result in @a result_pool.
  */
-svn_element_payload_t *
-svn_element_payload_create_ref(svn_revnum_t rev,
-                               const char *branch_id,
-                               int eid,
-                               apr_pool_t *result_pool);
+svn_element__payload_t *
+svn_element__payload_create_ref(svn_revnum_t rev,
+                                const char *branch_id,
+                                int eid,
+                                apr_pool_t *result_pool);
 
 /** Create a new node-payload object for a directory node.
  *
  * Allocate the result in @a result_pool.
  */
-svn_element_payload_t *
-svn_element_payload_create_dir(apr_hash_t *props,
-                               apr_pool_t *result_pool);
+svn_element__payload_t *
+svn_element__payload_create_dir(apr_hash_t *props,
+                                apr_pool_t *result_pool);
 
 /** Create a new node-payload object for a file node.
  *
  * Allocate the result in @a result_pool.
  */
-svn_element_payload_t *
-svn_element_payload_create_file(apr_hash_t *props,
-                                svn_stringbuf_t *text,
-                                apr_pool_t *result_pool);
+svn_element__payload_t *
+svn_element__payload_create_file(apr_hash_t *props,
+                                 svn_stringbuf_t *text,
+                                 apr_pool_t *result_pool);
 
 /** Create a new node-payload object for a symlink node.
  *
  * Allocate the result in @a result_pool.
  */
-svn_element_payload_t *
-svn_element_payload_create_symlink(apr_hash_t *props,
-                                   const char *target,
-                                   apr_pool_t *result_pool);
+svn_element__payload_t *
+svn_element__payload_create_symlink(apr_hash_t *props,
+                                    const char *target,
+                                    apr_pool_t *result_pool);
 
 /** @} */
 
@@ -263,37 +263,37 @@ svn_element_payload_create_symlink(apr_h
 /* The content (parent, name and payload) of an element-revision.
  * In other words, an el-rev node in a (mixed-rev) directory-tree.
  */
-typedef struct svn_element_content_t
+typedef struct svn_element__content_t
 {
   /* eid of the parent element, or -1 if this is the root element */
   int parent_eid;
   /* element name, or "" for root element; never null */
   const char *name;
   /* payload (kind, props, text, ...) */
-  svn_element_payload_t *payload;
+  svn_element__payload_t *payload;
 
-} svn_element_content_t;
+} svn_element__content_t;
 
 /* Return a new content object constructed with deep copies of PARENT_EID,
  * NAME and PAYLOAD, allocated in RESULT_POOL.
  */
-svn_element_content_t *
-svn_element_content_create(int parent_eid,
-                           const char *name,
-                           const svn_element_payload_t *payload,
-                           apr_pool_t *result_pool);
+svn_element__content_t *
+svn_element__content_create(int parent_eid,
+                            const char *name,
+                            const svn_element__payload_t *payload,
+                            apr_pool_t *result_pool);
 
 /* Return a deep copy of OLD, allocated in RESULT_POOL.
  */
-svn_element_content_t *
-svn_element_content_dup(const svn_element_content_t *old,
-                        apr_pool_t *result_pool);
+svn_element__content_t *
+svn_element__content_dup(const svn_element__content_t *old,
+                         apr_pool_t *result_pool);
 
 /* Return TRUE iff CONTENT_LEFT is the same as CONTENT_RIGHT. */
 svn_boolean_t
-svn_element_content_equal(const svn_element_content_t *content_left,
-                          const svn_element_content_t *content_right,
-                          apr_pool_t *scratch_pool);
+svn_element__content_equal(const svn_element__content_t *content_left,
+                           const svn_element__content_t *content_right,
+                           apr_pool_t *scratch_pool);
 
 /** @} */
 
@@ -324,34 +324,34 @@ svn_element_content_equal(const svn_elem
  * the repo), or as local stand-alone EIDs (in their own local name-space),
  * according to the context.
  */
-typedef struct svn_element_tree_t
+typedef struct svn_element__tree_t
 {
-  /* EID -> svn_branch_el_rev_content_t mapping. */
+  /* EID -> svn_element__content_t mapping. */
   apr_hash_t *e_map;
 
   /* Subtree root EID. (ROOT_EID must be an existing key in E_MAP.) */
   int root_eid;
 
-} svn_element_tree_t;
+} svn_element__tree_t;
 
 /* Create an element tree object.
  *
  * The result contains a *shallow* copy of E_MAP, or a new empty mapping
  * if E_MAP is null.
  */
-svn_element_tree_t *
-svn_element_tree_create(apr_hash_t *e_map,
-                        int root_eid,
-                        apr_pool_t *result_pool);
-
-svn_element_content_t *
-svn_element_tree_get(const svn_element_tree_t *tree,
-                     int eid);
+svn_element__tree_t *
+svn_element__tree_create(apr_hash_t *e_map,
+                         int root_eid,
+                         apr_pool_t *result_pool);
+
+svn_element__content_t *
+svn_element__tree_get(const svn_element__tree_t *tree,
+                      int eid);
 
 svn_error_t *
-svn_element_tree_set(svn_element_tree_t *tree,
-                     int eid,
-                     svn_element_content_t *element);
+svn_element__tree_set(svn_element__tree_t *tree,
+                      int eid,
+                      svn_element__content_t *element);
 
 /* Purge entries from E_MAP that don't connect, via parent directory hierarchy,
  * to ROOT_EID. In other words, remove elements that have been implicitly
@@ -363,9 +363,9 @@ svn_element_tree_set(svn_element_tree_t
  *     that is disconnected from ROOT_EID. This could be a problem.
  */
 void
-svn_element_tree_purge_orphans(apr_hash_t *e_map,
-                               int root_eid,
-                               apr_pool_t *scratch_pool);
+svn_element__tree_purge_orphans(apr_hash_t *e_map,
+                                int root_eid,
+                                apr_pool_t *scratch_pool);
 
 /* Return the subtree-relative path of element EID in TREE.
  *
@@ -374,9 +374,9 @@ svn_element_tree_purge_orphans(apr_hash_
  * ### TODO: Clarify sequencing requirements.
  */
 const char *
-svn_element_tree_get_path_by_eid(const svn_element_tree_t *tree,
-                                 int eid,
-                                 apr_pool_t *result_pool);
+svn_element__tree_get_path_by_eid(const svn_element__tree_t *tree,
+                                  int eid,
+                                  apr_pool_t *result_pool);
 
 /* Return the subtree rooted at EID within ELEMENT_TREE.
  *
@@ -384,10 +384,10 @@ svn_element_tree_get_path_by_eid(const s
  * shallow copy of the mapping in ELEMENT_TREE: the hash table is
  * duplicated but the keys and values (element content data) are not.
  */
-svn_element_tree_t *
-svn_element_tree_get_subtree_at_eid(svn_element_tree_t *element_tree,
-                                    int eid,
-                                    apr_pool_t *result_pool);
+svn_element__tree_t *
+svn_element__tree_get_subtree_at_eid(svn_element__tree_t *element_tree,
+                                     int eid,
+                                     apr_pool_t *result_pool);
 
 /** @} */
 
@@ -396,4 +396,4 @@ svn_element_tree_get_subtree_at_eid(svn_
 }
 #endif /* __cplusplus */
 
-#endif /* SVN_ELEMENT_H */
+#endif /* SVN_BRANCH_ELEMENT_H */

Modified: subversion/branches/move-tracking-2/subversion/include/private/svn_ra_private.h
URL: http://svn.apache.org/viewvc/subversion/branches/move-tracking-2/subversion/include/private/svn_ra_private.h?rev=1713980&r1=1713979&r2=1713980&view=diff
==============================================================================
--- subversion/branches/move-tracking-2/subversion/include/private/svn_ra_private.h (original)
+++ subversion/branches/move-tracking-2/subversion/include/private/svn_ra_private.h Thu Nov 12 08:59:57 2015
@@ -311,8 +311,8 @@ svn_ra__replay_ev2(svn_ra_session_t *ses
 /* Load branching info.
  */
 svn_error_t *
-svn_ra_load_branching_state(svn_branch_txn_t **branching_txn_p,
-                            svn_branch_compat__shim_fetch_func_t *fetch_func,
+svn_ra_load_branching_state(svn_branch__txn_t **branching_txn_p,
+                            svn_branch__compat_fetch_func_t *fetch_func,
                             void **fetch_baton,
                             svn_ra_session_t *session,
                             const char *branch_info_dir,
@@ -327,7 +327,7 @@ svn_ra_load_branching_state(svn_branch_t
  */
 svn_error_t *
 svn_ra_get_commit_txn(svn_ra_session_t *session,
-                      svn_branch_txn_t **edit_txn_p,
+                      svn_branch__txn_t **edit_txn_p,
                       apr_hash_t *revprop_table,
                       svn_commit_callback2_t commit_callback,
                       void *commit_baton,
@@ -346,7 +346,7 @@ svn_ra_do_update4(svn_ra_session_t *sess
                   svn_depth_t depth,
                   svn_boolean_t send_copyfrom_args,
                   svn_boolean_t ignore_ancestry,
-                  svn_update_editor3_t *update_editor,
+                  svn_branch__compat_update_editor3_t *update_editor,
                   apr_pool_t *result_pool,
                   apr_pool_t *scratch_pool);
 
@@ -361,7 +361,7 @@ svn_ra_do_switch4(svn_ra_session_t *sess
                   const char *switch_url,
                   svn_boolean_t send_copyfrom_args,
                   svn_boolean_t ignore_ancestry,
-                  svn_update_editor3_t *switch_editor,
+                  svn_branch__compat_update_editor3_t *switch_editor,
                   apr_pool_t *result_pool,
                   apr_pool_t *scratch_pool);
 

Modified: subversion/branches/move-tracking-2/subversion/include/private/svn_wc_private.h
URL: http://svn.apache.org/viewvc/subversion/branches/move-tracking-2/subversion/include/private/svn_wc_private.h?rev=1713980&r1=1713979&r2=1713980&view=diff
==============================================================================
--- subversion/branches/move-tracking-2/subversion/include/private/svn_wc_private.h (original)
+++ subversion/branches/move-tracking-2/subversion/include/private/svn_wc_private.h Thu Nov 12 08:59:57 2015
@@ -1455,7 +1455,7 @@ svn_wc__get_status_editor(const svn_delt
  * @since New in 1.8.
  */
 svn_error_t *
-svn_wc__get_update_editor_ev3(svn_update_editor3_t **update_editor,
+svn_wc__get_update_editor_ev3(svn_branch__compat_update_editor3_t **update_editor,
                           svn_revnum_t *target_revision,
                           svn_wc_context_t *wc_ctx,
                           const char *anchor_abspath,
@@ -1526,7 +1526,7 @@ svn_wc__get_update_editor(const svn_delt
  * @since New in 1.8.
  */
 svn_error_t *
-svn_wc__get_switch_editor_ev3(svn_update_editor3_t **update_editor,
+svn_wc__get_switch_editor_ev3(svn_branch__compat_update_editor3_t **update_editor,
                           svn_revnum_t *target_revision,
                           svn_wc_context_t *wc_ctx,
                           const char *anchor_abspath,

Modified: subversion/branches/move-tracking-2/subversion/libsvn_client/switch.c
URL: http://svn.apache.org/viewvc/subversion/branches/move-tracking-2/subversion/libsvn_client/switch.c?rev=1713980&r1=1713979&r2=1713980&view=diff
==============================================================================
--- subversion/branches/move-tracking-2/subversion/libsvn_client/switch.c (original)
+++ subversion/branches/move-tracking-2/subversion/libsvn_client/switch.c Thu Nov 12 08:59:57 2015
@@ -111,7 +111,7 @@ switch_internal(svn_revnum_t *result_rev
   apr_array_header_t *inherited_props;
   svn_boolean_t use_commit_times;
 #if 0
-  svn_update_editor3_t *switch_editor;
+  svn_branch__compat_update_editor3_t *switch_editor;
 #else
   const svn_delta_editor_t *switch_editor;
   void *switch_edit_baton;

Modified: subversion/branches/move-tracking-2/subversion/libsvn_client/update.c
URL: http://svn.apache.org/viewvc/subversion/branches/move-tracking-2/subversion/libsvn_client/update.c?rev=1713980&r1=1713979&r2=1713980&view=diff
==============================================================================
--- subversion/branches/move-tracking-2/subversion/libsvn_client/update.c (original)
+++ subversion/branches/move-tracking-2/subversion/libsvn_client/update.c Thu Nov 12 08:59:57 2015
@@ -692,7 +692,7 @@ update_internal(svn_revnum_t *result_rev
                 apr_pool_t *scratch_pool)
 {
 #if 0
-  svn_update_editor3_t *update_editor;
+  svn_branch__compat_update_editor3_t *update_editor;
 #else
   const svn_delta_editor_t *update_editor;
   void *update_edit_baton;
--- subversion/branches/move-tracking-2/subversion/include/private/svn_branch_nested.h (original)
+++ subversion/branches/move-tracking-2/subversion/include/private/svn_branch_nested.h Thu Nov 12 08:59:57 2015
@@ -43,18 +43,18 @@ extern "C" {
 /*
  */
 void
-svn_branch_get_outer_branch_and_eid(svn_branch_state_t **outer_branch_p,
-                                    int *outer_eid_p,
-                                    const svn_branch_state_t *branch,
-                                    apr_pool_t *scratch_pool);
+svn_branch__get_outer_branch_and_eid(svn_branch__state_t **outer_branch_p,
+                                     int *outer_eid_p,
+                                     const svn_branch__state_t *branch,
+                                     apr_pool_t *scratch_pool);
 
 /* Return the root repos-relpath of BRANCH.
  *
  * ### TODO: Clarify sequencing requirements.
  */
 const char *
-svn_branch_get_root_rrpath(const svn_branch_state_t *branch,
-                           apr_pool_t *result_pool);
+svn_branch__get_root_rrpath(const svn_branch__state_t *branch,
+                            apr_pool_t *result_pool);
 
 /* Return the repos-relpath of element EID in BRANCH.
  *
@@ -63,9 +63,9 @@ svn_branch_get_root_rrpath(const svn_bra
  * ### TODO: Clarify sequencing requirements.
  */
 const char *
-svn_branch_get_rrpath_by_eid(const svn_branch_state_t *branch,
-                             int eid,
-                             apr_pool_t *result_pool);
+svn_branch__get_rrpath_by_eid(const svn_branch__state_t *branch,
+                              int eid,
+                              apr_pool_t *result_pool);
 
 /* Return the EID for the repos-relpath RRPATH in BRANCH.
  *
@@ -74,9 +74,9 @@ svn_branch_get_rrpath_by_eid(const svn_b
  * ### TODO: Clarify sequencing requirements.
  */
 int
-svn_branch_get_eid_by_rrpath(svn_branch_state_t *branch,
-                             const char *rrpath,
-                             apr_pool_t *scratch_pool);
+svn_branch__get_eid_by_rrpath(svn_branch__state_t *branch,
+                              const char *rrpath,
+                              apr_pool_t *scratch_pool);
 
 /* Find the (deepest) branch of which the path RELPATH is either the root
  * path or a normal, non-sub-branch path. An element need not exist at
@@ -94,10 +94,10 @@ svn_branch_get_eid_by_rrpath(svn_branch_
  * ### TODO: Clarify sequencing requirements.
  */
 svn_error_t *
-svn_branch_find_nested_branch_element_by_relpath(
-                                svn_branch_state_t **branch_p,
+svn_branch__find_nested_branch_element_by_relpath(
+                                svn_branch__state_t **branch_p,
                                 int *eid_p,
-                                svn_branch_state_t *root_branch,
+                                svn_branch__state_t *root_branch,
                                 const char *relpath,
                                 apr_pool_t *scratch_pool);
 
@@ -114,8 +114,8 @@ svn_branch_find_nested_branch_element_by
  * ### TODO: Clarify sequencing requirements.
  */
 svn_error_t *
-svn_branch_repos_find_el_rev_by_path_rev(svn_branch_el_rev_id_t **el_rev_p,
-                                const svn_branch_repos_t *repos,
+svn_branch__repos_find_el_rev_by_path_rev(svn_branch__el_rev_id_t **el_rev_p,
+                                const svn_branch__repos_t *repos,
                                 svn_revnum_t revnum,
                                 const char *branch_id,
                                 const char *relpath,
@@ -126,45 +126,45 @@ svn_branch_repos_find_el_rev_by_path_rev
  * sub-branches of BRANCH.
  */
 svn_error_t *
-svn_branch_get_immediate_subbranches(svn_branch_state_t *branch,
-                                     apr_array_header_t **subbranches_p,
-                                     apr_pool_t *result_pool,
-                                     apr_pool_t *scratch_pool);
+svn_branch__get_immediate_subbranches(svn_branch__state_t *branch,
+                                      apr_array_header_t **subbranches_p,
+                                      apr_pool_t *result_pool,
+                                      apr_pool_t *scratch_pool);
 
 /* Return the subbranch rooted at BRANCH:EID, or NULL if that is
  * not a subbranch root.
  */
 svn_error_t *
-svn_branch_get_subbranch_at_eid(svn_branch_state_t *branch,
-                                svn_branch_state_t **subbranch_p,
-                                int eid,
-                                apr_pool_t *scratch_pool);
+svn_branch__get_subbranch_at_eid(svn_branch__state_t *branch,
+                                 svn_branch__state_t **subbranch_p,
+                                 int eid,
+                                 apr_pool_t *scratch_pool);
 
 /* A subtree of a branch, including any nested branches.
  */
-typedef struct svn_branch_subtree_t
+typedef struct svn_branch__subtree_t
 {
-  svn_branch_rev_bid_t *predecessor;
+  svn_branch__rev_bid_t *predecessor;
 
-  /* EID -> svn_branch_el_rev_content_t mapping. */
-  svn_element_tree_t *tree;
+  /* EID -> svn_element__content_t mapping. */
+  svn_element__tree_t *tree;
 
   /* Subbranches to be included: each subbranch-root element in E_MAP
      should be mapped here.
 
-     A mapping of (int)EID -> (svn_branch_subtree_t *). */
+     A mapping of (int)EID -> (svn_branch__subtree_t *). */
   apr_hash_t *subbranches;
-} svn_branch_subtree_t;
+} svn_branch__subtree_t;
 
 /* Create an empty subtree (no elements populated, not even ROOT_EID).
  *
  * The result contains a *shallow* copy of E_MAP, or a new empty mapping
  * if E_MAP is null.
  */
-svn_branch_subtree_t *
-svn_branch_subtree_create(apr_hash_t *e_map,
-                          int root_eid,
-                          apr_pool_t *result_pool);
+svn_branch__subtree_t *
+svn_branch__subtree_create(apr_hash_t *e_map,
+                           int root_eid,
+                           apr_pool_t *result_pool);
 
 /* Return the subtree of BRANCH rooted at EID.
  * Recursive: includes subbranches.
@@ -172,21 +172,21 @@ svn_branch_subtree_create(apr_hash_t *e_
  * The result is limited by the lifetime of BRANCH. It includes a shallow
  * copy of the element maps in BRANCH and its subbranches: the hash tables
  * are duplicated but the keys and values (element content data) are not.
  * It assumes that modifications on a svn_branch_state_t treat element
  * map keys and values as immutable -- which they do.
  */
 svn_error_t *
-svn_branch_get_subtree(svn_branch_state_t *branch,
-                       svn_branch_subtree_t **subtree_p,
-                       int eid,
-                       apr_pool_t *result_pool);
+svn_branch__get_subtree(svn_branch__state_t *branch,
+                        svn_branch__subtree_t **subtree_p,
+                        int eid,
+                        apr_pool_t *result_pool);
 
 /* Return the subbranch rooted at SUBTREE:EID, or NULL if that is
  * not a subbranch root. */
-svn_branch_subtree_t *
-svn_branch_subtree_get_subbranch_at_eid(svn_branch_subtree_t *subtree,
-                                        int eid,
-                                        apr_pool_t *result_pool);
+svn_branch__subtree_t *
+svn_branch__subtree_get_subbranch_at_eid(svn_branch__subtree_t *subtree,
+                                         int eid,
+                                         apr_pool_t *result_pool);
 
 /* Instantiate elements in a branch.
  *
@@ -197,16 +197,16 @@ svn_branch_subtree_get_subbranch_at_eid(
  * subbranches in TO_BRANCH, recursively.
  */
 svn_error_t *
-svn_branch_instantiate_elements_r(svn_branch_state_t *to_branch,
-                                  svn_branch_subtree_t elements,
-                                  apr_pool_t *scratch_pool);
+svn_branch__instantiate_elements_r(svn_branch__state_t *to_branch,
+                                   svn_branch__subtree_t elements,
+                                   apr_pool_t *scratch_pool);
 
 /* Create a branch txn object that implements nesting, and wraps a plain
  * branch txn (that doesn't support nesting) WRAPPED_TXN.
  */
-svn_branch_txn_t *
-svn_nested_branch_txn_create(svn_branch_txn_t *wrapped_txn,
-                             apr_pool_t *result_pool);
+svn_branch__txn_t *
+svn_branch__nested_txn_create(svn_branch__txn_t *wrapped_txn,
+                              apr_pool_t *result_pool);
 
 
 #ifdef __cplusplus
@@ -172,21 +172,21 @@ svn_branch_subtree_create(apr_hash_t *e_
  * copy of the element maps in BRANCH and its subbranches: the hash tables
  * are duplicated but the keys and values (element content data) are not.
- * It assumes that modifications on a svn_branch_state_t treat element
+ * It assumes that modifications on a svn_branch__state_t treat element
  * map keys and values as immutable -- which they do.
  */

Modified: subversion/branches/move-tracking-2/subversion/include/private/svn_branch_repos.h
URL: http://svn.apache.org/viewvc/subversion/branches/move-tracking-2/subversion/include/private/svn_branch_repos.h?rev=1713980&r1=1713979&r2=1713980&view=diff
==============================================================================